package Exception::Multistate::BadAction;
$Exception::Multistate::BadAction::VERSION = '0.010';
use base qw(Exception::Multistate);

1;
